@@ -2,7 +2,7 @@ package Crypt::NaCl::Tweet;
 use strict;
 use warnings;
 BEGIN {
-  our $VERSION = '0.03';
+  our $VERSION = '0.04';
   require XSLoader;
   XSLoader::load(__PACKAGE__, $VERSION);
 }
@@ -70,6 +70,7 @@ our %EXPORT_TAGS = (
     onetimeauth_KEYBYTES
     onetimeauth_PRIMITIVE
     onetimeauth
+    onetimeauth_keygen
     onetimeauth_verify
   ]],
   random => [qw[ random_bytes ]],
@@ -103,6 +104,7 @@ our %EXPORT_TAGS = (
     stream_NONCEBYTES
     stream_PRIMITIVE
     stream
+    stream_keygen
     stream_xor
   ]],
   verify => [qw[
@@ -157,6 +159,10 @@ sub box_keypair {
   return ($pk, $sk);
 }
 
+sub onetimeauth_keygen { random_bytes(onetimeauth_KEYBYTES) }
+
+sub stream_keygen { random_bytes(stream_KEYBYTES) }
+
 1;
 
 __END__
@@ -272,6 +278,10 @@ primitives.
 
   my $authenticator = onetimeauth($msg, $key);
 
+=item onetimeauth_keygen
+
+  my $auth_key = onetimeauth_keygen();
+
 =item onetimeauth_verify
 
   my $is_valid = onetimeauth_verify($authenticator, $msg, $key);
@@ -400,6 +410,10 @@ returns undef if signature is not valid.
 
   my $stream_bytes = stream($nbytes, $nonce, $key);
 
+=item stream_keygen
+
+  my $stream_key = stream_keygen();
+
 =item stream_xor
 
   my $ciphertext = stream_xor($msg, $nonce, $key);
